@@ -8,17 +8,13 @@
 # @Software     : PyCharm
 # @Description  : 
 
+from meutils.common import *
+from meutils.zk_utils import get_zk_config
+from appzoo import App
 
-import os
-import requests
-
-import numpy as np
 from paddleocr import PaddleOCR
 from PIL import Image
 
-from appzoo import App
-from appzoo.utils.zk_utils import get_zk_config
-
 ac_url = get_zk_config('/mipush/cfg')['ac_url']
 
 ocr = PaddleOCR(use_angle_cls=True, lang="ch")
