@@ -8,23 +8,24 @@
 # @Software     : PyCharm
 # @Description  :
 
+from meutils.common import *
+from meutils.np_utils import normalize
+from meutils.zk_utils import get_zk_config
+from appzoo import App
 
-import os
-import keras
+import tensorflow as tf
+
+keras = tf.keras
+
+os.environ['TF_KERAS'] = '1'
 
 from bert4keras.models import build_transformer_model
 from bert4keras.tokenizers import Tokenizer
 from bert4keras.snippets import sequence_padding
 
-from functools import lru_cache
-from loguru import logger
-
-from appzoo import App
-from appzoo.utils import normalize, cfg
-
 # BERT_DIR
 BERT_DIR = './chinese_simbert_L-12_H-768_A-12'
-fds_url = cfg['fds_url']
+fds_url = get_zk_config("/mipush/cfg")['fds_url']
 
 if not os.path.exists(BERT_DIR):
     url = f"{fds_url}/data/bert/chinese_simbert_L-12_H-768_A-12.zip"
@@ -48,13 +49,15 @@ bert = build_transformer_model(
 
 encoder = keras.models.Model(bert.model.inputs, bert.model.outputs[0])
 
-
 # seq2seq = keras.models.Model(bert.model.inputs, bert.model.outputs[1])
+maxlen = 64
+
 
 @lru_cache(10240)
 def text2vec(text):
-    token_ids, segment_ids = tokenizer.encode(text, maxlen=128)
-    vecs = encoder.predict([sequence_padding([token_ids]), sequence_padding([segment_ids])])
+    token_ids, segment_ids = tokenizer.encode(text, maxlen=maxlen)
+    data = [sequence_padding([token_ids], length=maxlen), sequence_padding([segment_ids], length=maxlen)]
+    vecs = encoder.predict(data)
     return vecs
 
 
@@ -62,11 +65,11 @@ def texts2vec(texts):
     X = []
     S = []
     for text in texts:
-        token_ids, segment_ids = tokenizer.encode(text, maxlen=128)
+        token_ids, segment_ids = tokenizer.encode(text, maxlen=maxlen)
         X.append(token_ids)
         S.append(segment_ids)
-
-    vecs = encoder.predict([sequence_padding(X), sequence_padding(S)])
+    data = [sequence_padding(X, length=maxlen), sequence_padding(S, length=maxlen)]
+    vecs = encoder.predict(data)
     return vecs
 
 
